@@ -23,7 +23,7 @@ import pylint_secure_coding_standard as pylint_scs
 class TestSecureCodingStandardChecker(pylint.testutils.CheckerTestCase):
     CHECKER_CLASS = pylint_scs.SecureCodingStandardChecker
 
-    def test_yaml_ok(self):
+    def test_jsonpickle_decode_ok(self):
         nodes = astroid.extract_node(
             """
             int(0) #@
@@ -41,7 +41,7 @@ class TestSecureCodingStandardChecker(pylint.testutils.CheckerTestCase):
         's',
         ('jsonpickle.decode(payload)',),
     )
-    def test_yaml_not_ok(self, s):
+    def test_jsonpickle_decode_not_ok(self, s):
         node = astroid.extract_node(s + ' #@')
         with self.assertAddsMessages(pylint.testutils.Message(msg_id='avoid-jsonpickle-decode', node=node)):
             self.checker.visit_call(node)
